#!/bin/bash
# packager           : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://laurikari.net/tre/download.html
# last revised       : 13/10/07

softname='tre'
softversion='0.7.5'
packageversion='50.1'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: POSIX compliant regexp matching library
$softname: 
$softname: TRE is a lightweight, robust, and efficient POSIX compliant
$softname: regexp matching library with some exciting features such as   
$softname: approximate (fuzzy) matching.
$softname: 
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --mandir=/usr/man \
      --program-prefix="" \
      --program-suffix="" \

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      ABOUT-NLS AUTHORS COPYING.LESSER ChangeLog INSTALL LICENSE NEWS README THANKS TODO \
      $dest/usr/doc/$softname-$softversion
      
# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
